@@ -2,9 +2,9 @@ import os
 current_dir = os.path.dirname(os.path.realpath(__file__)) + "/"
 
 filenames = [
-    "ex-benchmark-and-fork/ex-benchmark-and-fork.py", "ex-fodo/ex-fodos.py", "ex-lhc-couplingLocal/lhc-couplingLocal.py",
+    "ex-benchmark-and-fork/ex-benchmark-and-fork.py", "ex-fodo/ex-fodos.py", "ex-lhc-couplingLocal/ex-lhc-couplingLocal.py",
     "ex-managing-refs/ex-managing-refs.py", "ex-LowLevel/ex-send-multypes.py", "ex-LowLevel/ex-send-recv.py", 
-    "ex-ps-twiss/ps-twiss.py", "ex-recv-lhc/ex-defexpr.py"
+    "ex-ps-twiss/ex-ps-twiss.py", "ex-recv-lhc/ex-defexpr.py"
     ]
 for name in filenames:
     print(name)
