@@ -1,10 +1,10 @@
-from .mad_object import MAD
+from .madp_object import MAD
 
 __title__ = "pymadng"
-__version__ = "0.3.8"
+__version__ = "0.7.1"
 
 __summary__ = "Python interface to MAD-NG running as subprocess"
-__uri__ = "https://github.com/MethodicalAcceleratorDesign/MADpy"
+__uri__ = "https://github.com/MethodicalAcceleratorDesign/MAD-NG.py"
 
 __credits__ = """
 Creator: Joshua Gray <joshua.mark.gray at cern.ch>
